@@ -2,7 +2,7 @@
 /**
  * Instance of a single permissioning object.
  *
- * Copyright 2009-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -171,7 +171,7 @@ class Horde_Perms_Permission
 
                 /* If nothing to actually update finish with this case. */
                 if (is_null($perm_values)) {
-                    continue;
+                    break;
                 }
 
                 /* Loop through the names and update permissions for each. */
